==> fess-9.1.0.tar.gz: fess/src/main/java/jp/sf/fess/db/cbean/nss/LabelTypeToRoleTypeMappingNss.java <==
/*
 * Copyright 2009-2014 the CodeLibs Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.db.cbean.nss;

import jp.sf.fess.db.cbean.cq.LabelTypeToRoleTypeMappingCQ;

import org.seasar.dbflute.cbean.ConditionQuery;

/**
 * The nest select set-upper of LABEL_TYPE_TO_ROLE_TYPE_MAPPING.
 * @author DBFlute(AutoGenerator)
 */
public class LabelTypeToRoleTypeMappingNss {

    // ===================================================================================
    //                                                                           Attribute
    //                                                                           =========
    protected LabelTypeToRoleTypeMappingCQ _query;

    public LabelTypeToRoleTypeMappingNss(
            final LabelTypeToRoleTypeMappingCQ query) {
        _query = query;
    }

    public boolean hasConditionQuery() {
        return _query != null;
    }

    // ===================================================================================
    //                                                                     Nested Relation
    //                                                                     ===============
    /**
     * With nested relation columns to select clause. <br />
     * LABEL_TYPE by my LABEL_TYPE_ID, named 'labelType'.
     * @return The set-upper of more nested relation. {...with[nested-relation].with[more-nested-relation]} (NotNull)
     */
    public LabelTypeNss withLabelType() {
        _query.doNss(new LabelTypeToRoleTypeMappingCQ.NssCall() {
            @Override
            public ConditionQuery qf() {
                return _query.queryLabelType();
            }
        });
        return new LabelTypeNss(_query.queryLabelType());
    }

    /**
     * With nested relation columns to select clause. <br />
     * ROLE_TYPE by my ROLE_TYPE_ID, named 'roleType'.
     * @return The set-upper of more nested relation. {...with[nested-relation].with[more-nested-relation]} (NotNull)
     */
    public RoleTypeNss withRoleType() {
        _query.doNss(new LabelTypeToRoleTypeMappingCQ.NssCall() {
            @Override
            public ConditionQuery qf() {
                return _query.queryRoleType();
            }
        });
        return new RoleTypeNss(_query.queryRoleType());
    }

}

==> fess-9.3.0.tar.gz: fess/src/main/java/jp/sf/fess/db/cbean/nss/LabelTypeToRoleTypeMappingNss.java <==
/*
 * Copyright 2009-2014 the CodeLibs Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.db.cbean.nss;

import jp.sf.fess.db.cbean.cq.LabelTypeToRoleTypeMappingCQ;

import org.seasar.dbflute.cbean.ConditionQuery;

/**
 * The nest select set-upper of LABEL_TYPE_TO_ROLE_TYPE_MAPPING.
 * @author DBFlute(AutoGenerator)
 */
public class LabelTypeToRoleTypeMappingNss {

    // ===================================================================================
    //                                                                           Attribute
    //                                                                           =========
    protected LabelTypeToRoleTypeMappingCQ _query;

    public LabelTypeToRoleTypeMappingNss(
            final LabelTypeToRoleTypeMappingCQ query) {
        _query = query;
    }

    public boolean hasConditionQuery() {
        return _query != null;
    }

    // ===================================================================================
    //                                                                     Nested Relation
    //                                                                     ===============
    /**
     * With nested relation columns to select clause. <br />
     * LABEL_TYPE by my LABEL_TYPE_ID, named 'labelType'.
     */
    public void withLabelType() {
        _query.doNss(new LabelTypeToRoleTypeMappingCQ.NssCall() {
            @Override
            public ConditionQuery qf() {
                return _query.queryLabelType();
            }
        });
    }

    /**
     * With nested relation columns to select clause. <br />
     * ROLE_TYPE by my ROLE_TYPE_ID, named 'roleType'.
     */
    public void withRoleType() {
        _query.doNss(new LabelTypeToRoleTypeMappingCQ.NssCall() {
            @Override
            public ConditionQuery qf() {
                return _query.queryRoleType();
            }
        });
    }
}
